pub struct InterviewStartedEvent {
pub authority: Pubkey,
pub interview_id: [u8; 32],
pub job_listing_id: [u8; 32],
pub timestamp: i64,
}Fields
interview_id: [u8; 32]job_listing_id: [u8; 32]timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for InterviewStartedEvent
impl BorshDeserialize for InterviewStartedEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for InterviewStartedEvent
impl Discriminator for InterviewStartedEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more