pub struct UserBannedEvent {
pub authority: Pubkey,
pub is_permanent: bool,
pub ban_expires_at: Option<i64>,
pub timestamp: i64,
}Fields
is_permanent: boolban_expires_at: Option<i64>timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for UserBannedEventwhere
Pubkey: BorshDeserialize,
bool: BorshDeserialize,
Option<i64>: BorshDeserialize,
i64: BorshDeserialize,
impl BorshDeserialize for UserBannedEventwhere
Pubkey: BorshDeserialize,
bool: BorshDeserialize,
Option<i64>: BorshDeserialize,
i64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UserBannedEventwhere
Pubkey: BorshSerialize,
bool: BorshSerialize,
Option<i64>: BorshSerialize,
i64: BorshSerialize,
impl BorshSerialize for UserBannedEventwhere
Pubkey: BorshSerialize,
bool: BorshSerialize,
Option<i64>: BorshSerialize,
i64: BorshSerialize,
Sourceimpl Discriminator for UserBannedEvent
impl Discriminator for UserBannedEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more